@@ -858,74 +858,6 @@ class keyed_memoize_method(keyed_memoize_on_first_arg):  # noqa: N801
         return intern(f"_memoize_dic_{function.__name__}")
 
 
-def memoize_method_with_uncached(uncached_args=None, uncached_kwargs=None):
-    """Supports cache deletion via ``method_name.clear_cache(self)``.
-
-    :arg uncached_args: a list of argument numbers
-        (0-based, not counting 'self' argument)
-    """
-    from warnings import warn
-    warn("memoize_method_with_uncached is deprecated and will go away in 2022. "
-            "Use memoize_method_with_key instead",
-            DeprecationWarning,
-            stacklevel=2)
-
-    if uncached_args is None:
-        uncached_args = []
-    if uncached_kwargs is None:
-        uncached_kwargs = set()
-
-    # delete starting from the end
-    uncached_args = sorted(uncached_args, reverse=True)
-    uncached_kwargs = list(uncached_kwargs)
-
-    def parametrized_decorator(method):
-        cache_dict_name = intern(f"_memoize_dic_{method.__name__}")
-
-        def wrapper(self, *args, **kwargs):
-            cache_args = list(args)
-            cache_kwargs = kwargs.copy()
-
-            for i in uncached_args:
-                if i < len(cache_args):
-                    cache_args.pop(i)
-
-            cache_args = tuple(cache_args)
-
-            if kwargs:
-                for name in uncached_kwargs:
-                    cache_kwargs.pop(name, None)
-
-                key = (
-                        (_HasKwargs, frozenset(cache_kwargs.items()))
-                        + cache_args)
-            else:
-                key = cache_args
-
-            try:
-                return getattr(self, cache_dict_name)[key]
-            except AttributeError:
-                result = method(self, *args, **kwargs)
-                object.__setattr__(self, cache_dict_name, {key: result})
-                return result
-            except KeyError:
-                result = method(self, *args, **kwargs)
-                getattr(self, cache_dict_name)[key] = result
-                return result
-
-        def clear_cache(self):
-            object.__delattr__(self, cache_dict_name)
-
-        if sys.version_info >= (2, 5):
-            from functools import update_wrapper
-            new_wrapper = update_wrapper(wrapper, method)
-            new_wrapper.clear_cache = clear_cache
-
-        return new_wrapper
-
-    return parametrized_decorator
-
-
 class memoize_in:  # noqa
     """Adds a cache to the function it decorates. The cache is attached
     to *container* and must be uniquely specified by *identifier* (i.e.
@@ -2311,8 +2243,14 @@ class UniqueNameGenerator:
         """
         pass
 
-    def add_name(self, name: str) -> None:
-        if self.is_name_conflicting(name):
+    def add_name(self, name: str, *, conflicting_ok: bool = False) -> None:
+        """
+        :arg conflicting_ok: A flag to dictate the behavior when *name* is
+            conflicting with the set of existing names. If *True*, a conflict
+            is silently passed. If *False*, a :class:`ValueError` is raised on
+            encountering a conflict.
+        """
+        if (not conflicting_ok) and self.is_name_conflicting(name):
             raise ValueError(f"name '{name}' conflicts with existing names")
 
         if not name.startswith(self.forced_prefix):
@@ -2323,9 +2261,14 @@ class UniqueNameGenerator:
         self.existing_names.add(name)
         self._name_added(name)
 
-    def add_names(self, names: Iterable[str]) -> None:
+    def add_names(self, names: Iterable[str],
+                  *,
+                  conflicting_ok: bool = False) -> None:
+        """
+        :arg conflicting_ok: Plainly passed to :meth:`UniqueNameGenerator.add_name`.
+        """
         for name in names:
-            self.add_name(name)
+            self.add_name(name, conflicting_ok=conflicting_ok)
 
     def __call__(self, based_on: str = "id") -> str:
         based_on = self.forced_prefix + based_on
